//
//  LGE_Viscosity.c
//  AGA
//
//  Created by Rodrigo Carvajal on 08/Jul/13.
//  Copyright (c) 2013 Rodrigo Carvajal. All rights reserved.
//

#include <math.h>
#include "LGE_Viscosity.h"

double LGE_Viscosity(double T, double Rho, double MW) {
    /*
     Inputs
         T    = Temperature, K
         Rho  = Density, kg/m^3
         MW   = Gas Molecular Weight, kg/kg-mole
     
     Return
         Viscosity, cP
     
     */
    
    // Change units to required values
    double rho = Rho / 1000.0;  // Convert kg/m^3 to g/cc
    double T_R = T * 1.8;       // Convert Kelvin to Rankine
    
    // Determine Visocosity utilizing Lee, Gonzalez, and Eakin Correlation
    // Lee, A., Gonzalex, M., Ekain, B. (1966), "The Viscosity of Natural Gases", SPE Paper 1340
    // Jouranl of Petroleum Technology, vol, 18, p. 997-1000.
    double X = 3.448 + (986.4/T_R) + (0.01009*MW);
    double Y = 2.447 - 0.2224*X;
    double K = ((9.379+0.01607*MW)*pow(T_R,1.5)) / (209.2+(19.26*MW)+T_R);
    
    return K * exp(X*pow(rho, Y)) / 10000.0;    // Return viscosity in cP
}