//
//  main.c
//  MMCheck
//
//  Created by Rodrigo Carvajal on 09/Jul/13.
//  Copyright (c) 2013 Rodrigo Carvajal. All rights reserved.
//

#include <math.h>
#include "mathlink.h"
#include "AGA8_Properties.h"


void GetNGProp(double P, double T, double *MF, int MFLen, int Property) {
    /*
     Inputs:
         P    = Pressure, psia
         T    = Temperature, ˚F
         MF[] = Pointer to array of Mole Fractions of the format:
                 0  Not Used (use zero)
                 1	Methane
                 2	Nitrogen
                 3	Carbon Dioxide
                 4	Ethane
                 5	Propane
                 6	Water
                 7	Hydrogen Sulfide
                 8	Hydrogen
                 9	Carbon Monoxide
                 10	Oxygen
                 11	i-Butane
                 12	n-Butane
                 13	i-Pentane
                 14	n-Pentane
                 15	n-Hexane
                 16	n-Heptane
                 17	n-Octane
                 18	n-Nonane
                 19	n-Decane
                 20	Helium
                 21	Argon
         MFLen = Length of MF array (22)
     
     Property = Indication of what to return,
                 1 = Molecular Weight
                 2 = Second Viral Coefficient, m^3/kg-mole
                 3 = Density, lbm/ft^3
                 4 = Compressibility Factor
                 5 = dBdT, Derivative of the Second Viral Coefficient wrt T at constant d
                 6 = d2BdT2, Second derivative of the Second Viral Coefficient wrt T at constant d
                 7 = Isochoric specific heat, Btu/lbm-R
                 8 = Isobaric specific heat, Btu/lbm-R
                 9 = Speed of Sound, ft/sec
                 10 = Isentropic exponent, Dimensionless
                 11 = Specific Enthalpy, Btu/lbm
                 12 = Specific Entropy, Btu/lbm-R
                 13 = Dynamic Viscosity, cP
     
     Errors:
         -1000.0 =   Too many iterations
         -2000.0 =   Unknown Property
         -3000.0 =   Real Gas Error
     
     */
    double Check = AGA8_Properties(P, T, MF, Property);
    
    if ( Check < -999.0) {
        
        switch ( (int)Check ) {
            case -1000:
                MLPutString(stdlink, "Natural Gas Error: Too many iterations.");
                break;
                
            case -2000:
                MLPutString(stdlink, "Natural Gas Error: Unknown Property.");
                break;
                
            case -3000:
                MLPutString(stdlink, "Natural Gas Error: Real Gas Calculation Error.");
                break;
            
            default:
                MLPutString(stdlink, "Natural Gass Error: Unknown Error.");
                break;
        };
    }
    else {
        MLPutReal64(stdlink, Check);
    };
    
    return;
}



int main(int argc, char* argv[]) {

    return MLMain(argc, argv);
    
}

